@@ -37,7 +37,7 @@ import static java.security.AccessController.getContext;
  */
 final class ClassLoaderLocalLoader implements LocalLoader {
 
-    static final LocalLoader SYSTEM = JDKSpecific.getSystemLocalLoader();
+    static final LocalLoader SYSTEM = Utils.getSystemLocalLoader();
 
     private final ClassLoader classLoader;
     private final AccessControlContext context;
@@ -70,7 +70,7 @@ final class ClassLoaderLocalLoader implements LocalLoader {
     }
 
     public Package loadPackageLocal(final String name) {
-        return JDKSpecific.getPackage(classLoader, name);
+        return classLoader.getDefinedPackage(name);
     }
 
     public List<Resource> loadResourceLocal(final String name) {
@@ -78,7 +78,7 @@ final class ClassLoaderLocalLoader implements LocalLoader {
         ClassLoader classLoader = this.classLoader;
         try {
             if (classLoader == null) {
-                urls = JDKSpecific.getSystemResources(name);
+                urls = Utils.getSystemResources(name);
             } else {
                 urls = classLoader.getResources(name);
             }
