@@ -54,8 +54,11 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
 
     /**
      * An empty enumeration, for subclasses to use if desired.
+     *
+     * @deprecated Use {@link Collections#emptyEnumeration()} instead.
      */
-    protected static final Enumeration<URL> EMPTY_ENUMERATION = Collections.enumeration(Collections.<URL>emptySet());
+    @Deprecated
+    protected static final Enumeration<URL> EMPTY_ENUMERATION = Collections.emptyEnumeration();
 
     /**
      * Construct a new instance with the given parent class loader, which must be a concurrent class loader, or {@code null}
@@ -82,8 +85,8 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
      * @param name the name of this class loader, or {@code null} if it is unnamed
      */
     protected ConcurrentClassLoader(final ConcurrentClassLoader parent, final String name) {
-        super(parent == null ? JDKSpecific.getPlatformClassLoader() : parent, name);
-        if (! JDKSpecific.isParallelCapable(this)) {
+        super(parent == null ? Utils.getPlatformClassLoader() : parent, name);
+        if (! isRegisteredAsParallelCapable()) {
             throw new Error("Cannot instantiate non-parallel subclass");
         }
     }
@@ -94,16 +97,12 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
      * @param name the name of this class loader, or {@code null} if it is unnamed
      */
     protected ConcurrentClassLoader(String name) {
-        super(JDKSpecific.getPlatformClassLoader(), name);
-        if (! JDKSpecific.isParallelCapable(this)) {
+        super(Utils.getPlatformClassLoader(), name);
+        if (! isRegisteredAsParallelCapable()) {
             throw new Error("Cannot instantiate non-parallel subclass");
         }
     }
 
-    static Object getLockForClass(ConcurrentClassLoader cl, String name) {
-        return cl.getClassLoadingLock(name);
-    }
-
     /**
      * Loads the class with the specified binary name.  Equivalent to calling {@link #loadClass(String, boolean) loadClass(className, false)}.
      *
@@ -179,8 +178,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
      */
     protected final Class<?> defineOrLoadClass(final String className, final byte[] bytes, int off, int len) {
         try {
-            final Class<?> definedClass = defineClass(className, bytes, off, len);
-            return definedClass;
+            return defineClass(className, bytes, off, len);
         } catch (LinkageError e) {
             final Class<?> loadedClass = findLoadedClass(className);
             if (loadedClass != null) {
@@ -249,7 +247,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
     public final URL getResource(final String name) {
         for (String s : Module.systemPaths) {
             if (name.startsWith(s)) {
-                return JDKSpecific.getSystemResource(name);
+                return Utils.getSystemResource(name);
             }
         }
         return findResource(name, false);
@@ -267,7 +265,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
     public final Enumeration<URL> getResources(final String name) throws IOException {
         for (String s : Module.systemPaths) {
             if (name.startsWith(s)) {
-                return JDKSpecific.getSystemResources(name);
+                return Utils.getSystemResources(name);
             }
         }
         return findResources(name, false);
@@ -322,7 +320,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
      * @throws IOException if an I/O error occurs
      */
     protected Enumeration<URL> findResources(final String name, final boolean exportsOnly) throws IOException {
-        return EMPTY_ENUMERATION;
+        return Collections.emptyEnumeration();
     }
 
     /**
@@ -334,7 +332,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
      * @return an empty enumeration
      */
     protected final Enumeration<URL> findResources(final String name) {
-        return EMPTY_ENUMERATION;
+        return Collections.emptyEnumeration();
     }
 
     /**
@@ -362,7 +360,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
     public final InputStream getResourceAsStream(final String name) {
         for (String s : Module.systemPaths) {
             if (name.startsWith(s)) {
-                return JDKSpecific.getSystemResourceAsStream(name);
+                return Utils.getSystemResourceAsStream(name);
             }
         }
         return findResourceAsStream(name, false);
@@ -392,7 +390,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
         }
         for (String s : Module.systemPackages) {
             if (className.startsWith(s)) {
-                return JDKSpecific.getSystemClass(this, className);
+                return Utils.getSystemClass(this, className);
             }
         }
         return performLoadClassUnchecked(className, exportsOnly, resolve);
@@ -421,7 +419,9 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
      *
      * @param name the package name
      * @return the package, or {@code null} if no such package is visible to this class loader
+     * @deprecated Deprecated in {@link ClassLoader#getPackage(String)}.
      */
+    @Deprecated
     protected final Package getPackage(final String name) {
         final String packageName = name + ".";
         for (String s : Module.systemPackages) {
@@ -456,7 +456,7 @@ public abstract class ConcurrentClassLoader extends NamedClassLoader {
         ArrayList<Package> list = new ArrayList<>();
         list.addAll(packages.values());
         list.addAll(Arrays.asList(super.getPackages()));
-        return list.toArray(new Package[list.size()]);
+        return list.toArray(Package[]::new);
     }
 
     /**
