@@ -59,7 +59,9 @@ public final class JarModuleFinder implements ModuleFinder {
      *
      * @param myIdentifier the identifier to use for the JAR itself
      * @param jarFile the JAR file to encapsulate
+     * @deprecated Use {@link #JarModuleFinder(String,JarFile)} instead.
      */
+    @Deprecated(forRemoval = true)
     public JarModuleFinder(final ModuleIdentifier myIdentifier, final JarFile jarFile) {
         this(myIdentifier.toString(), jarFile);
     }
@@ -124,7 +126,7 @@ public final class JarModuleFinder implements ModuleFinder {
                         // assume a JAR
                         JarFile childJarFile;
                         try {
-                            childJarFile = JDKSpecific.getJarFile(root, true);
+                            childJarFile = new JarFile(root, true, JarFile.OPEN_READ, JarFile.runtimeVersion());
                         } catch (IOException e) {
                             // ignore and continue
                             continue;
