@@ -99,7 +99,7 @@ class LayeredModulePathFactory {
             }
         }
 
-        return foundLayers ? layeredPath.toArray(new File[layeredPath.size()]) : modulePath;
+        return foundLayers ? layeredPath.toArray(File[]::new) : modulePath;
     }
 
     private static LayersConfig getLayersConfig(File repoRoot) {
@@ -195,11 +195,20 @@ class LayeredModulePathFactory {
 
         final File overlays = new File(layeringRoot, OVERLAYS);
         if (overlays.exists()) {
+            if (!overlays.canRead()) {
+                throw new IllegalStateException("Overlays directory exists but is not readable: " + overlays.getPath());
+            }
             final File refs = new File(overlays, OVERLAYS);
             if (refs.exists()) {
+                if (!refs.canRead()) {
+                    throw new IllegalStateException("Overlays metadata file exists but is not readable: " + refs.getPath());
+                }
                 try {
                     for (final String overlay : readRefs(refs)) {
                         final File root = new File(overlays, overlay);
+                        if (!root.exists() || !root.canRead()) {
+                            throw new IllegalStateException("Overlay root directory doesn't exists or is not readable: " + root.getPath());
+                        }
                         path.add(root);
                     }
                 } catch (IOException e) {
