@@ -155,9 +155,6 @@ public final class Main {
                         }
                         modulePath = args[++i];
                         System.setProperty("module.path", modulePath);
-                    } else if ("-config".equals(arg)) {
-                        System.err.println("Config files are no longer supported.  Use the -mp option instead");
-                        System.exit(1);
                     } else if ("-deptree".equals(arg)) {
                         if (depTree) {
                             System.err.println("-deptree may only be specified once");
@@ -283,6 +280,12 @@ public final class Main {
                 System.exit(1);
             }
         }
+        int actualVersion = Runtime.version().feature();
+
+        if (actualVersion >= 24 && (secMgrModule != null || defaultSecMgr)) {
+            System.err.printf("The security manager is not supported in Java %d.", Runtime.version().feature());
+            System.exit(1);
+        }
 
         if (deps != null && ! classDefined && ! classpathDefined) {
             System.err.println("-deps may only be specified when -cp/-classpath or -class is in use");
@@ -361,63 +364,65 @@ public final class Main {
             System.exit(1);
             return;
         }
-        final String ourJavaVersion = doPrivileged(new PropertyReadAction("java.specification.version", "1.6"));
-        final String requireJavaVersion = module.getProperty("jboss.require-java-version", ourJavaVersion);
+        final String requireJavaVersion = module.getProperty("jboss.require-java-version", Integer.toString(actualVersion));
         final Pattern versionPattern = Pattern.compile("(?:1\\.)?(\\d+)");
         final Matcher requireMatcher = versionPattern.matcher(requireJavaVersion);
-        final Matcher ourMatcher = versionPattern.matcher(ourJavaVersion);
-        if (requireMatcher.matches() && ourMatcher.matches() && Integer.parseInt(requireMatcher.group(1)) > Integer.parseInt(ourMatcher.group(1))) {
-            System.err.printf("This application requires Java specification version %s or later to run (this Java virtual machine implements specification version %s)%n", requireJavaVersion, ourJavaVersion);
+        if (requireMatcher.matches() && Integer.parseInt(requireMatcher.group(1)) > actualVersion) {
+            System.err.printf("This application requires Java specification version %s or later to run (this Java virtual machine implements specification version %s)%n", requireJavaVersion, Integer.valueOf(actualVersion));
             System.exit(1);
         }
 
-        ModularURLStreamHandlerFactory.addHandlerModule(module);
+        ModularURLStreamHandlerProvider.addHandlerModule(module);
         ModularContentHandlerFactory.addHandlerModule(module);
 
-        // at this point, having a security manager already installed will prevent correct operation.
+        if (actualVersion < 24) {
+            // at this point, having a security manager already installed will prevent correct operation.
 
-        final SecurityManager existingSecMgr = System.getSecurityManager();
-        if (existingSecMgr != null) {
-            System.err.println("An existing security manager was detected.  You must use the -secmgr switch to start with a security manager.");
-            System.exit(1);
-            return; // not reached
-        }
-
-        try {
-            final Iterator<Policy> iterator = module.loadService(Policy.class).iterator();
-            if (iterator.hasNext()) {
-                Policy.setPolicy(iterator.next());
+            final SecurityManager existingSecMgr = System.getSecurityManager();
+            if (existingSecMgr != null) {
+                System.err.println("An existing security manager was detected.  You must use the -secmgr switch to start with a security manager.");
+                System.exit(1);
+                return; // not reached
             }
-        } catch (Exception ignored) {}
 
-        // configure policy so that if SM is enabled, modules can still function
-        final ModulesPolicy policy = new ModulesPolicy(Policy.getPolicy());
-        Policy.setPolicy(policy);
-
-        if (secMgrModule != null) {
-            final Module loadedModule;
             try {
-                loadedModule = environmentLoader.loadModule(secMgrModule);
-            } catch (ModuleNotFoundException e) {
-                e.printStackTrace(System.err);
-                System.exit(1);
-                return;
+                final Iterator<Policy> iterator = module.loadService(Policy.class).iterator();
+                if (iterator.hasNext()) {
+                    Policy.setPolicy(iterator.next());
+                }
+            } catch (Exception ignored) {
             }
-            final Iterator<SecurityManager> iterator = ServiceLoader.load(SecurityManager.class, loadedModule.getClassLoaderPrivate()).iterator();
-            if (iterator.hasNext()) {
-                System.setSecurityManager(iterator.next());
-            } else {
-                System.err.println("No security manager found in module " + secMgrModule);
-                System.exit(1);
-            }
-        }
 
-        if (defaultSecMgr) {
-            final Iterator<SecurityManager> iterator = module.loadService(SecurityManager.class).iterator();
-            if (iterator.hasNext()) {
-                System.setSecurityManager(iterator.next());
-            } else {
-                System.setSecurityManager(new SecurityManager());
+            // configure policy so that if SM is enabled, modules can still function
+            final ModulesPolicy policy = new ModulesPolicy(Policy.getPolicy());
+            Policy.setPolicy(policy);
+
+            if (secMgrModule != null) {
+                final Module loadedModule;
+                try {
+                    loadedModule = environmentLoader.loadModule(secMgrModule);
+                } catch (ModuleNotFoundException e) {
+                    e.printStackTrace(System.err);
+                    System.exit(1);
+                    return;
+                }
+                final Iterator<SecurityManager> iterator = ServiceLoader.load(SecurityManager.class, loadedModule.getClassLoaderPrivate())
+                        .iterator();
+                if (iterator.hasNext()) {
+                    System.setSecurityManager(iterator.next());
+                } else {
+                    System.err.println("No security manager found in module " + secMgrModule);
+                    System.exit(1);
+                }
+            }
+
+            if (defaultSecMgr) {
+                final Iterator<SecurityManager> iterator = module.loadService(SecurityManager.class).iterator();
+                if (iterator.hasNext()) {
+                    System.setSecurityManager(iterator.next());
+                } else {
+                    System.setSecurityManager(new SecurityManager());
+                }
             }
         }
 
