@@ -18,6 +18,8 @@
 
 package org.jboss.modules;
 
+import static java.security.AccessController.doPrivileged;
+
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.invoke.MethodHandle;
@@ -39,7 +41,6 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
-import java.util.ListIterator;
 import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.ServiceLoader;
@@ -101,25 +102,18 @@ public final class Module {
                 } else {
                     part = pkgsString.substring(i, nc).trim();
                 }
-                if (part.length() > 0) {
+                if (! part.isEmpty()) {
                     list.add((part + ".").intern());
                 }
             } while (nc != -1);
         }
-        final String[] noStrings = new String[0];
-        systemPackages = list.toArray(noStrings);
-        final ListIterator<String> iterator = list.listIterator();
-        // http://youtrack.jetbrains.net/issue/IDEA-72097
-        //noinspection WhileLoopReplaceableByForEach
-        while (iterator.hasNext()) {
-            iterator.set(iterator.next().replace('.', '/'));
-        }
-        systemPaths = list.toArray(noStrings);
+        systemPackages = list.toArray(String[]::new);
+        systemPaths = list.stream().map(i -> i.replace('.', '/')).toArray(String[]::new);
 
         AccessController.doPrivileged(new PrivilegedAction<Void>() {
             public Void run() {
                 try {
-                    URL.setURLStreamHandlerFactory(ModularURLStreamHandlerFactory.INSTANCE);
+                    URL.setURLStreamHandlerFactory(ModularURLStreamHandlerProvider.INSTANCE);
                 } catch (Throwable t) {
                     // todo log a warning or something
                 }
@@ -150,7 +144,7 @@ public final class Module {
      * @throws SecurityException always
      */
     public static ModulesPrivateAccess getPrivateAccess() {
-        if (JDKSpecific.getCallingClass() == ModularPermissionFactory.class) {
+        if (STACK_WALKER.getCallerClass() == ModularPermissionFactory.class) {
             return PRIVATE_ACCESS;
         }
         throw new SecurityException();
@@ -218,7 +212,6 @@ public final class Module {
     private static final RuntimePermission ACCESS_MODULE_LOGGER;
     private static final RuntimePermission ADD_CONTENT_HANDLER_FACTORY;
     private static final RuntimePermission ADD_URL_STREAM_HANDLER_FACTORY;
-
     private static final PermissionCollection NO_PERMISSIONS = noPermissions();
 
     /**
@@ -341,7 +334,7 @@ public final class Module {
             } catch (Throwable t) {
                 throw new InvocationTargetException(t, "Failed to initialize main class '" + className + "'");
             }
-            final MethodHandles.Lookup lookup = MethodHandles.lookup();
+            final MethodHandles.Lookup lookup = MethodHandles.publicLookup();
             final MethodHandle methodHandle;
             try {
                 methodHandle = lookup.findStatic(mainClass, "main", MAIN_METHOD_TYPE);
@@ -364,7 +357,7 @@ public final class Module {
      * @return the identifier
      * @deprecated Use {@link #getName()} instead.
      */
-    @Deprecated
+    @Deprecated(forRemoval = true)
     public ModuleIdentifier getIdentifier() {
         return ModuleIdentifier.fromString(getName());
     }
@@ -395,6 +388,7 @@ public final class Module {
      * @return the service loader
      */
     public <S> ServiceLoader<S> loadService(Class<S> serviceType) {
+        getClass().getModule().addUses(serviceType);
         return ServiceLoader.load(serviceType, moduleClassLoader);
     }
 
@@ -406,6 +400,7 @@ public final class Module {
      * @return the service loader
      */
     public <S> ServiceLoader<S> loadServiceDirectly(Class<S> serviceType) {
+        getClass().getModule().addUses(serviceType);
         return ServiceLoader.load(serviceType, new ClassLoader(null) {
             public Enumeration<URL> getResources(final String name) throws IOException {
                 final Enumeration<Resource> resourceEnumeration = Collections.enumeration(getClassLoader().getLocalLoader().loadResourceLocal(name));
@@ -428,16 +423,26 @@ public final class Module {
      * Note that {@link #loadService(Class)} is more efficient since it does not need to crawl
      * the stack.
      *
-     * @param <S> the the service type
+     * @param <S> the service type
      * @param identifier the module identifier containing the service loader
      * @param serviceType the service type class
      * @return the loaded service from the caller's module
      * @throws ModuleLoadException if the named module failed to load
      * @deprecated Use {@link #loadServiceFromCallerModuleLoader(String, Class)} instead.
      */
-    @Deprecated
+    @Deprecated(forRemoval = true)
     public static <S> ServiceLoader<S> loadServiceFromCallerModuleLoader(ModuleIdentifier identifier, Class<S> serviceType) throws ModuleLoadException {
-        return loadServiceFromCallerModuleLoader(identifier.toString(), serviceType);
+        Class<?> caller = STACK_WALKER.getCallerClass();
+        assert ! caller.getPackageName().equals(Module.class.getPackageName());
+        String name = identifier.toString();
+        Module callerModule = forClass(caller);
+        if (callerModule != null) {
+            ModuleLoader ml = callerModule.getModuleLoader();
+            if (ml != null) {
+                return ml.loadModule(name).loadService(serviceType);
+            }
+        }
+        throw new ModuleLoadException(name);
     }
 
     /**
@@ -446,16 +451,21 @@ public final class Module {
      * Note that {@link #loadService(Class)} is more efficient since it does not need to crawl
      * the stack.
      *
-     * @param <S> the the service type
+     * @param <S> the service type
      * @param name the module name containing the service loader
      * @param serviceType the service type class
      * @return the loaded service from the caller's module
      * @throws ModuleLoadException if the named module failed to load
      */
     public static <S> ServiceLoader<S> loadServiceFromCallerModuleLoader(String name, Class<S> serviceType) throws ModuleLoadException {
-        ModuleLoader ml = getCallerModuleLoader();
-        if (ml != null) {
-            return ml.loadModule(name).loadService(serviceType);
+        Class<?> caller = STACK_WALKER.getCallerClass();
+        assert ! caller.getPackageName().equals(Module.class.getPackageName());
+        Module callerModule = forClass(caller);
+        if (callerModule != null) {
+            ModuleLoader ml = callerModule.getModuleLoader();
+            if (ml != null) {
+                return ml.loadModule(name).loadService(serviceType);
+            }
         }
         throw new ModuleLoadException(name);
     }
@@ -569,7 +579,7 @@ public final class Module {
         if (loader == null) {
             throw new IllegalArgumentException("loader is null");
         }
-        return JDKSpecific.findServices(type, filter, loader);
+        return Utils.findServices(type, filter, loader);
     }
 
     static void initBootModuleLoader(ModuleLoader loader) {
@@ -585,8 +595,7 @@ public final class Module {
      * @return the current module loader, or {@code null} if this method is called outside of a module
      */
     public static ModuleLoader getCallerModuleLoader() {
-        Module callerModule = getCallerModule();
-        return callerModule == null ? null : callerModule.getModuleLoader();
+        return ModuleLoader.forClass(STACK_WALKER.getCallerClass());
     }
 
     /**
@@ -604,6 +613,8 @@ public final class Module {
         return null;
     }
 
+    static final StackWalker STACK_WALKER = doPrivileged((PrivilegedAction<StackWalker>) () -> StackWalker.getInstance(StackWalker.Option.RETAIN_CLASS_REFERENCE));
+
     /**
      * Get a module from the current module loader. Note that this must crawl the
      * stack to determine this, so other mechanisms are more efficient.
@@ -614,9 +625,16 @@ public final class Module {
      * @throws ModuleLoadException if the module could not be loaded
      * @deprecated Use {@link #getModuleFromCallerModuleLoader(String)} instead.
      */
-    @Deprecated
+    @Deprecated(forRemoval = true)
     public static Module getModuleFromCallerModuleLoader(final ModuleIdentifier identifier) throws ModuleLoadException {
-        return getModuleFromCallerModuleLoader(identifier.toString());
+        final String name = identifier.toString();
+        Class<?> caller = STACK_WALKER.getCallerClass();
+        assert ! caller.getPackageName().equals(Module.class.getPackageName());
+        ModuleLoader ml = ModuleLoader.forClass(caller);
+        if (ml != null) {
+            return ml.loadModule(name);
+        }
+        throw new ModuleLoadException(name);
     }
 
     /**
@@ -629,7 +647,9 @@ public final class Module {
      * @throws ModuleLoadException if the module could not be loaded
      */
     public static Module getModuleFromCallerModuleLoader(final String name) throws ModuleLoadException {
-        ModuleLoader ml = getCallerModuleLoader();
+        Class<?> caller = STACK_WALKER.getCallerClass();
+        assert ! caller.getPackageName().equals(Module.class.getPackageName());
+        ModuleLoader ml = ModuleLoader.forClass(caller);
         if (ml != null) {
             return ml.loadModule(name);
         }
@@ -644,7 +664,7 @@ public final class Module {
      * @return the current module
      */
     public static Module getCallerModule() {
-        return forClass(JDKSpecific.getCallingUserClass());
+        return forClass(STACK_WALKER.getCallerClass());
     }
 
     /**
@@ -655,7 +675,7 @@ public final class Module {
      * @throws ModuleLoadException if an error occurs
      * @deprecated Use {@link #getModule(String)} instead.
      */
-    @Deprecated
+    @Deprecated(forRemoval = true)
     public Module getModule(final ModuleIdentifier identifier) throws ModuleLoadException {
         return getModule(identifier.toString());
     }
@@ -684,7 +704,7 @@ public final class Module {
      * @throws ClassNotFoundException if the class could not be loaded
      * @deprecated Use {@link #loadClassFromBootModuleLoader(String, String)} instead.
      */
-    @Deprecated
+    @Deprecated(forRemoval = true)
     public static Class<?> loadClassFromBootModuleLoader(final ModuleIdentifier moduleIdentifier, final String className)
             throws ModuleLoadException, ClassNotFoundException {
         return loadClassFromBootModuleLoader(moduleIdentifier.toString(), className);
@@ -704,7 +724,7 @@ public final class Module {
      */
     public static Class<?> loadClassFromBootModuleLoader(final String name, final String className)
             throws ModuleLoadException, ClassNotFoundException {
-        return Class.forName(className, true, getBootModuleLoader().loadModule(name).getClassLoader());
+        return Class.forName(className, true, getBootModuleLoader().loadModule(name).getClassLoaderPrivate());
     }
 
     /**
@@ -720,10 +740,17 @@ public final class Module {
      * @throws ClassNotFoundException if the class could not be loaded
      * @deprecated Use {@link #loadClassFromCallerModuleLoader(String, String)} instead.
      */
-    @Deprecated
+    @Deprecated(forRemoval = true)
     public static Class<?> loadClassFromCallerModuleLoader(final ModuleIdentifier moduleIdentifier, final String className)
             throws ModuleLoadException, ClassNotFoundException {
-        return loadClassFromCallerModuleLoader(moduleIdentifier.toString(), className);
+        Class<?> caller = STACK_WALKER.getCallerClass();
+        assert ! caller.getPackageName().equals(Module.class.getPackageName());
+        ModuleLoader ml = ModuleLoader.forClass(caller);
+        String name = moduleIdentifier.toString();
+        if (ml != null) {
+            return Class.forName(className, true, ml.loadModule(name).getClassLoaderPrivate());
+        }
+        throw new ModuleLoadException(name);
     }
 
     /**
@@ -740,7 +767,13 @@ public final class Module {
      */
     public static Class<?> loadClassFromCallerModuleLoader(final String name, final String className)
             throws ModuleLoadException, ClassNotFoundException {
-        return Class.forName(className, true, getModuleFromCallerModuleLoader(name).getClassLoader());
+        Class<?> caller = STACK_WALKER.getCallerClass();
+        assert ! caller.getPackageName().equals(Module.class.getPackageName());
+        ModuleLoader ml = ModuleLoader.forClass(caller);
+        if (ml != null) {
+            return Class.forName(className, true, ml.loadModule(name).getClassLoaderPrivate());
+        }
+        throw new ModuleLoadException(name);
     }
 
     /**
@@ -860,7 +893,7 @@ public final class Module {
                 try {
                     return moduleClassLoader.getResources(canonPath);
                 } catch (IOException e) {
-                    return ConcurrentClassLoader.EMPTY_ENUMERATION;
+                    return Collections.emptyEnumeration();
                 }
             }
         }
@@ -886,7 +919,7 @@ public final class Module {
             }
         }
 
-        return list.size() == 0 ? ConcurrentClassLoader.EMPTY_ENUMERATION : Collections.enumeration(list);
+        return Collections.enumeration(list);
     }
 
     /**
@@ -1072,7 +1105,7 @@ public final class Module {
      * @return the property value
      */
     public String getProperty(String name, String defaultVal) {
-        return properties.containsKey(name) ? properties.get(name) : defaultVal;
+        return properties.getOrDefault(name, defaultVal);
     }
 
     /**
@@ -1189,7 +1222,7 @@ public final class Module {
         if (sm != null) {
             sm.checkPermission(ADD_URL_STREAM_HANDLER_FACTORY);
         }
-        ModularURLStreamHandlerFactory.addHandlerModule(module);
+        ModularURLStreamHandlerProvider.addHandlerModule(module);
     }
 
     /**
@@ -1262,7 +1295,7 @@ public final class Module {
                     if (moduleDependency.isOptional()) {
                         continue;
                     } else {
-                        log.trace("Module %s, dependency %s preload failed: %s", getIdentifier(), moduleDependency.getName(), ex);
+                        log.trace("Module %s, dependency %s preload failed: %s", getName(), moduleDependency.getName(), ex);
                         throw ex;
                     }
                 }
@@ -1413,7 +1446,7 @@ public final class Module {
                         if (moduleDependency.isOptional()) {
                             continue;
                         } else {
-                            log.trace("Module %s, dependency %s preload failed: %s", getIdentifier(), moduleDependency.getName(), ex);
+                            log.trace("Module %s, dependency %s preload failed: %s", getName(), moduleDependency.getName(), ex);
                             throw ex;
                         }
                     }
@@ -1675,7 +1708,7 @@ public final class Module {
         if (dependencySpecs == null) {
             throw new IllegalArgumentException("dependencySpecs is null");
         }
-        final DependencySpec[] specs = dependencySpecs.toArray(new DependencySpec[dependencySpecs.size()]);
+        final DependencySpec[] specs = dependencySpecs.toArray(DependencySpec[]::new);
         for (DependencySpec spec : specs) {
             if (spec == null) {
                 throw new IllegalArgumentException("dependencySpecs contains a null dependency specification");
@@ -1727,6 +1760,6 @@ public final class Module {
                 continue next;
             }
         }
-        return packages.toArray(new Package[packages.size()]);
+        return packages.toArray(Package[]::new);
     }
 }
