@@ -71,7 +71,7 @@ public class ModuleClassLoader extends ConcurrentClassLoader {
     private final Module module;
     private final ClassTransformer transformer;
 
-    private final AtomicReference<Paths<ResourceLoader, ResourceLoaderSpec>> paths = new AtomicReference<>(Paths.<ResourceLoader, ResourceLoaderSpec>none());
+    private final AtomicReference<Paths<ResourceLoader, ResourceLoaderSpec>> paths = new AtomicReference<>(Paths.none());
 
     private final LocalLoader localLoader = new IterableLocalLoader() {
         public Class<?> loadClassLocal(final String name, final boolean resolve) {
@@ -102,7 +102,7 @@ public class ModuleClassLoader extends ConcurrentClassLoader {
         }
 
         public String toString() {
-            return "local loader for " + ModuleClassLoader.this.toString();
+            return "local loader for " + ModuleClassLoader.this;
         }
     };
 
@@ -114,7 +114,7 @@ public class ModuleClassLoader extends ConcurrentClassLoader {
     protected ModuleClassLoader(final Configuration configuration) {
         super(configuration.getModule().getModuleLoader().getModuleDescription(configuration.getModule()));
         module = configuration.getModule();
-        paths.lazySet(new Paths<>(configuration.getResourceLoaders(), Collections.<String, List<ResourceLoader>>emptyMap()));
+        paths.lazySet(new Paths<>(configuration.getResourceLoaders(), Collections.emptyMap()));
         final AssertionSetting setting = configuration.getAssertionSetting();
         if (setting != AssertionSetting.INHERIT) {
             setDefaultAssertionStatus(setting == AssertionSetting.ENABLED);
@@ -177,6 +177,7 @@ public class ModuleClassLoader extends ConcurrentClassLoader {
     /** {@inheritDoc} */
     @Override
     protected final Class<?> findClass(String className, boolean exportsOnly, final boolean resolve) throws ClassNotFoundException {
+        className = className.replace('/', '.');
         // Check if we have already loaded it..
         Class<?> loadedClass = findLoadedClass(className);
         if (loadedClass != null) {
@@ -489,6 +490,7 @@ public class ModuleClassLoader extends ConcurrentClassLoader {
                     final String oldMsg = e.getMessage();
                     final String newMsg = "Failed to link " + name.replace('.', '/') + " (" + module + ")";
                     ne = e.getClass().getConstructor(String.class).newInstance(oldMsg == null || oldMsg.isEmpty() ? newMsg : newMsg + ": " + oldMsg);
+                    ne.initCause(e.getCause());
                     ne.setStackTrace(e.getStackTrace());
                 } catch (InstantiationException | NoSuchMethodException | InvocationTargetException | IllegalAccessException ignored) {
                     // just throw the original
