@@ -50,7 +50,7 @@ public final class ModularPermissionFactory implements PermissionFactory {
      * @param permissionActions the action list to pass to the permission class constructor or {@code null} for none
      * @deprecated Use {@link #ModularPermissionFactory(ModuleLoader, String, String, String, String)} instead.
      */
-    @Deprecated
+    @Deprecated(forRemoval = true)
     public ModularPermissionFactory(final ModuleLoader moduleLoader, final ModuleIdentifier moduleIdentifier, final String className, final String targetName, final String permissionActions) {
         this(moduleLoader, moduleIdentifier.toString(), className, targetName, permissionActions);
     }
@@ -94,6 +94,7 @@ public final class ModularPermissionFactory implements PermissionFactory {
                 final Class<? extends Permission> permissionClass = access.getClassLoaderOf(module).loadClass(className, true).asSubclass(Permission.class);
                 return instance = PermissionFactory.constructFromClass(permissionClass, targetName, permissionActions);
             } catch (Throwable t) {
+                Module.getModuleLogger().trace(t, "Failed to construct permission instance: %s in %s", className, moduleName);
                 instance = null;
                 return null;
             }
