@@ -1,13 +1,13 @@
 /*
- * JBoss, Home of Professional Open Source
- * Copyright 2016, Red Hat, Inc., and individual contributors as indicated
- * by the @authors tag.
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2016 Red Hat, Inc., and individual contributors
+ * as indicated by the @author tags.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -63,7 +63,7 @@ public class ResourceRootPathsTest extends AbstractModuleTestCase {
 
     @Before
     public void setupModuleLoader() throws Exception {
-        repoRoot = tmpDir.newFolder("repo");
+        repoRoot = tmpDir.newFolder("repo").getCanonicalFile();
         testModuleRoot = new File(repoRoot, "test/test/main/");
 
         // Build a jar in module
@@ -100,13 +100,13 @@ public class ResourceRootPathsTest extends AbstractModuleTestCase {
                 final File jar = getFileFromJarUri(resourceLoader.getLocation());
 
                 // validate jar with relative path
-                if (testModuleRoot.equals(jar.getParentFile())) {
+                if (testModuleRoot.equals(jar.getParentFile().getCanonicalFile())) {
                     checkCount++;
                     continue;
                 }
 
                 // validate jar with absolute path
-                if (repoRoot.equals(jar.getParentFile())) {
+                if (repoRoot.equals(jar.getParentFile().getCanonicalFile())) {
                     checkCount++;
                     continue;
                 }
